﻿/*
 * eeprom.h
 * 
 * Модуль для работы с EEPROM
 *
 * Author: Погребняк Дмитрий
 * 
 * Помещённый здесь код является свободным. Т.е. допускается его свободное использование для любых целей, включая коммерческие, при условии указания ссылки на автора (Погребняк Дмитрий, http://aterlux.ru/).
 * Code included here is free to use. It can be used for free for any purpose, including commercial use, as long as link to author (Pogrebnyak Dmitry, http://aterlux.ru/) is included.
 */ 


#ifndef EEPROM_H_
#define EEPROM_H_

#include <avr/io.h>

// Тип для указания адреса в eeprom
#ifdef EEARH
typedef uint8_t eeprom_addr_t;
#else
typedef uint16_t eeprom_addr_t;
#endif

// Чтение одного байта
// return_if_0xFF - значение которое будет возвращено, если прочитано 0xFF (начальное значение в стёртой ячейке)
uint8_t eeprom_read(eeprom_addr_t address, uint8_t return_if_0xFF);

// Запись одного байта
void eeprom_write(eeprom_addr_t address, uint8_t data);

// Чтение двух байт 
// return_if_0xFFFF - значение которое будет возвращено, если оба байта 0xFF (начальное значение в стёртых ячейках)
int16_t eeprom_read_int16(eeprom_addr_t address, int16_t return_if_0xFFFF);

// Запись двух байт
void eeprom_write_int16(eeprom_addr_t address, int16_t data);

// Чтение count байт, начиная с адреса address в буфер buf
// Возвращает 0, если все прочитанные байты равны 0xFF; не ноль - если прочитан хотя бы один байт не равный 0xFF
uint8_t eeprom_read_buf(eeprom_addr_t address, uint8_t count, uint8_t * buf);

// Запись count байт из буфера buf, в адреса начиная с address
void eeprom_write_buf(eeprom_addr_t address, uint8_t * buf, uint8_t count);



#endif /* EEPROM_H_ */